@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2012-2017 by the Free Software Foundation, Inc.
+# Copyright (C) 2012-2019 by the Free Software Foundation, Inc.
 #
 # This file is part of HyperKitty.
 #
@@ -19,9 +19,9 @@
 # Author: Aurelien Bompard <abompard@fedoraproject.org>
 #
 
-from rest_framework import serializers, generics
+from rest_framework import generics, serializers
 
-from hyperkitty.models import MailingList, ArchivePolicy
+from hyperkitty.models import ArchivePolicy, MailingList
 from .utils import EnumField, IsMailingListPublicOrIsMember
 
 
